************
django-terms
************

Site-wide adds a definition or a link for specialized terms.

.. image:: https://raw.github.com/BertrandBordage/django-terms/master/example_project/screenshot.png

Code statistics:

.. image:: https://www.openhub.net/p/django-terms/widgets/project_thin_badge.gif
    :target: https://www.openhub.net/p/django-terms

PyPI status:

.. image:: https://pypip.in/v/django-terms/badge.png
    :target: https://crate.io/packages/django-terms/

.. image:: https://pypip.in/d/django-terms/badge.png
    :target: https://crate.io/packages/django-terms/

Continuous integration status:

.. image:: https://travis-ci.org/BertrandBordage/django-terms.png
    :target: https://travis-ci.org/BertrandBordage/django-terms

.. image:: https://coveralls.io/repos/BertrandBordage/django-terms/badge.png
    :target: https://coveralls.io/r/BertrandBordage/django-terms



Documentation
=============

Available `on Read The Docs <https://django-terms.readthedocs.org/en/latest/>`_.
